@@ -120,7 +120,7 @@ class RangeSpecifier:
             return Specifier(constr.replace('.*', '.0'))
 
         version = parse(constr.lstrip(OPERATOR_SYMBOLS).rstrip('.*'))
-        parts = version.release[:-1] + (version.release[-1] + 1, )
+        parts = version.release[:-1] + (version.release[-1] + 1, )  # type: ignore
         return Specifier(constr[:2] + '.'.join(map(str, parts)))
 
     @staticmethod
@@ -163,8 +163,12 @@ class RangeSpecifier:
                 right = '{}.*'.format(version.release[0])
             else:
                 right = '.'.join([parts[0], parts[1], '*'])
+        else:
+            RuntimeError('unreachable')
 
         left = '.'.join(parts[:3])
+        if version.pre:
+            left += '.' + ''.join(map(str, version.pre))
         return {Specifier('>=' + left), Specifier('==' + right)}
 
     def attach_time(self, releases) -> bool:
@@ -216,7 +220,7 @@ class RangeSpecifier:
             elif left is None or python > left:
                 excluded.append(python)
         if right is not None:
-            right = (pythons + [None])[pythons.index(right) + 1]
+            right = (pythons + [None])[pythons.index(right) + 1]  # type: ignore
 
         # get excluded intervals
         if right is not None:
